elephant.spike\_train\_surrogates.JointISI
==========================================

.. currentmodule:: elephant.spike_train_surrogates

.. autoclass:: JointISI
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~JointISI.__init__
      ~JointISI.dithering
      ~JointISI.joint_isi_histogram
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~JointISI.MIN_SPIKES
      ~JointISI.bin_width
      ~JointISI.isi
      ~JointISI.num_bins
      ~JointISI.refr_period
   
   